﻿using System;
using Microsoft.EntityFrameworkCore.Migrations;
using Npgsql.EntityFrameworkCore.PostgreSQL.Metadata;

#nullable disable

namespace Persistence.PostgreSql.Migrations
{
    /// <inheritdoc />
    public partial class Countries_Regions_Cities : Migration
    {
        /// <inheritdoc />
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.EnsureSchema(
                name: "application");

            migrationBuilder.AlterDatabase()
                .Annotation("Npgsql:Enum:vehicle_type", "bus,train,aircraft");

            migrationBuilder.CreateSequence(
                name: "cities_id_sequence",
                schema: "application");

            migrationBuilder.CreateSequence(
                name: "countries_id_sequence",
                schema: "application");

            migrationBuilder.CreateSequence(
                name: "regions_id_sequence",
                schema: "application");

            migrationBuilder.CreateTable(
                name: "countries",
                schema: "application",
                columns: table => new
                {
                    id = table.Column<long>(type: "bigint", nullable: false, defaultValueSql: "nextval('application.countries_id_sequence')"),
                    name = table.Column<string>(type: "varchar(64)", nullable: false),
                    uuid = table.Column<Guid>(type: "uuid", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_countries", x => x.id);
                    table.UniqueConstraint("altk_countries_Guid", x => x.uuid);
                });

            migrationBuilder.CreateTable(
                name: "Route",
                schema: "application",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    Name = table.Column<string>(type: "text", nullable: false),
                    Guid = table.Column<Guid>(type: "uuid", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Route", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "regions",
                schema: "application",
                columns: table => new
                {
                    id = table.Column<long>(type: "bigint", nullable: false, defaultValueSql: "nextval('application.regions_id_sequence')"),
                    name = table.Column<string>(type: "varchar(64)", nullable: false),
                    country_id = table.Column<long>(type: "bigint", nullable: false),
                    uuid = table.Column<Guid>(type: "uuid", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_regions", x => x.id);
                    table.UniqueConstraint("altk_regions_Guid", x => x.uuid);
                    table.ForeignKey(
                        name: "fk_regions_country_id",
                        column: x => x.country_id,
                        principalSchema: "application",
                        principalTable: "countries",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "cities",
                schema: "application",
                columns: table => new
                {
                    id = table.Column<long>(type: "bigint", nullable: false, defaultValueSql: "nextval('application.cities_id_sequence')"),
                    name = table.Column<string>(type: "varchar(64)", nullable: false),
                    region_id = table.Column<long>(type: "bigint", nullable: false),
                    uuid = table.Column<Guid>(type: "uuid", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_cities", x => x.id);
                    table.UniqueConstraint("altk_cities_Guid", x => x.uuid);
                    table.ForeignKey(
                        name: "fk_cities_region_id",
                        column: x => x.region_id,
                        principalSchema: "application",
                        principalTable: "regions",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "Address",
                schema: "application",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    Name = table.Column<string>(type: "text", nullable: false),
                    CityId = table.Column<long>(type: "bigint", nullable: false),
                    Guid = table.Column<Guid>(type: "uuid", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Address", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Address_cities_CityId",
                        column: x => x.CityId,
                        principalSchema: "application",
                        principalTable: "cities",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "RouteAddress",
                schema: "application",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    Order = table.Column<short>(type: "smallint", nullable: false),
                    AddressId = table.Column<long>(type: "bigint", nullable: false),
                    RouteId = table.Column<long>(type: "bigint", nullable: false),
                    Guid = table.Column<Guid>(type: "uuid", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_RouteAddress", x => x.Id);
                    table.ForeignKey(
                        name: "FK_RouteAddress_Address_AddressId",
                        column: x => x.AddressId,
                        principalSchema: "application",
                        principalTable: "Address",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_RouteAddress_Route_RouteId",
                        column: x => x.RouteId,
                        principalSchema: "application",
                        principalTable: "Route",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateIndex(
                name: "IX_Address_CityId",
                schema: "application",
                table: "Address",
                column: "CityId");

            migrationBuilder.CreateIndex(
                name: "ix_cities_id",
                schema: "application",
                table: "cities",
                column: "id",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_cities_region_id",
                schema: "application",
                table: "cities",
                column: "region_id");

            migrationBuilder.CreateIndex(
                name: "ix_cities_uuid",
                schema: "application",
                table: "cities",
                column: "uuid",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "ix_countries_id",
                schema: "application",
                table: "countries",
                column: "id",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "ix_countries_uuid",
                schema: "application",
                table: "countries",
                column: "uuid",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_regions_country_id",
                schema: "application",
                table: "regions",
                column: "country_id");

            migrationBuilder.CreateIndex(
                name: "ix_regions_id",
                schema: "application",
                table: "regions",
                column: "id",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "ix_regions_uuid",
                schema: "application",
                table: "regions",
                column: "uuid",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_RouteAddress_AddressId",
                schema: "application",
                table: "RouteAddress",
                column: "AddressId");

            migrationBuilder.CreateIndex(
                name: "IX_RouteAddress_RouteId",
                schema: "application",
                table: "RouteAddress",
                column: "RouteId");
        }

        /// <inheritdoc />
        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "RouteAddress",
                schema: "application");

            migrationBuilder.DropTable(
                name: "Address",
                schema: "application");

            migrationBuilder.DropTable(
                name: "Route",
                schema: "application");

            migrationBuilder.DropTable(
                name: "cities",
                schema: "application");

            migrationBuilder.DropTable(
                name: "regions",
                schema: "application");

            migrationBuilder.DropTable(
                name: "countries",
                schema: "application");

            migrationBuilder.DropSequence(
                name: "cities_id_sequence",
                schema: "application");

            migrationBuilder.DropSequence(
                name: "countries_id_sequence",
                schema: "application");

            migrationBuilder.DropSequence(
                name: "regions_id_sequence",
                schema: "application");
        }
    }
}
